@@ -209,3 +209,36 @@ class Trie(object):
             data: data to be paired with the key
         """
         return self.root.remove(iterable, data=data)
+
+    def scan(self, match_func):
+        """Traverse the trie scanning for end nodes with matching data.
+
+        Arguments:
+            match_func (callable): function used to match data.
+
+        Returns:
+            (list) list with matching (data, value) pairs.
+        """
+        def _traverse(node, match_func, current=''):
+            """Traverse Trie searching for nodes with matching data
+
+            Performs recursive depth first search of Trie and collects
+            value / data pairs matched by the match_func
+
+            Arguments:
+                node (trie node): Node to parse
+                match_func (callable): Function performing match
+                current (str): string "position" in Trie
+
+            Returns:
+                (list) list with matching (data, value) pairs.
+            """
+            # Check if node matches
+            result = [(current, d) for d in node.data if match_func(d)]
+
+            # Traverse further down into the tree
+            for c in node.children:
+                result += _traverse(node.children[c], match_func, current + c)
+            return result
+
+        return _traverse(self.root, match_func)
